//=============================================================================
//  @brief  DPI methods for RESSL ( command completion using GNU readline )
//  @author Bryan Morris, Jeff McNeal, Verilab (www.verilab.com)
// =============================================================================
//
//                      RESSL SystemVerilab Utilities Library
//
// @File: ressl_dpi.c
//     Plaese note: The base code for command completion was taken from the
//     following URL:
//        http://cc.byexamples.com/2008/06/16/gnu-readline-implement-custom-auto-complete/
//
// Copyright 2015 Verilab, Inc.
// 
//    Licensed under the Apache License, Version 2.0 (the "License");
//    you may not use this file except in compliance with the License.
//    You may obtain a copy of the License at
// 
//        http://www.apache.org/licenses/LICENSE-2.0
// 
//    Unless required by applicable law or agreed to in writing, software
//    distributed under the License is distributed on an "AS IS" BASIS,
//    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//    See the License for the specific language governing permissions and
//    limitations under the License.
//=============================================================================
#include <stdio.h>
#include <stdlib.h>
#include <readline/readline.h>
#include <readline/history.h>
 
#include <veriuser.h>
#include <vpi_user.h>
#include <svdpi.h>

#ifdef _CPLUSPLUS
extern "C" {
#endif

static char** my_completion(const char*, int ,int);
char* my_generator(const char*,int);
char * dupstr (char*);
void *xmalloc (int);
 
char* cmd [] ={ 
    "help",
 
    "list", 
    "describe",

    "select", 
    "create",
    "set",
    "add",
    "move",
    //"copy",

    "attach",

    "start",
    "randomize",
                
    "load",
    "save",

    "quit", 
    '\0'
};

/*-------------------------------------------------------------------------------
 * import "DPI-C" function int ressl_dpi_imported_setup_readline( )
 *-------------------------------------------------------------------------------
 * Function to return the user input from the command line.
 *-------------------------------------------------------------------------------
 */
extern int  ressl_dpi_imported_setup_readline(  )
{
    rl_attempted_completion_function = my_completion;
    //enable auto-complete
    rl_bind_key('\t',rl_complete);
 
    return 0;
}

/*-------------------------------------------------------------------------------
 * import "DPI-C" function string ressl_dpi_imported_readline(const char *)
 *-------------------------------------------------------------------------------
 * Function to return the user input from the command line.
 *-------------------------------------------------------------------------------
 */
extern const char * ressl_dpi_imported_readline(const char *cur_seq_name )
{
    char *buf;
    char *cmd_prefix;
    int   rc;
 
    cmd_prefix = xmalloc( strlen( cur_seq_name ) + 10 );
    rc = sprintf( cmd_prefix, "\n[%s] >>> ", cur_seq_name );
    
    if ((buf = readline(cmd_prefix))!=NULL) {
        //        printf("cmd [%s]\n",buf);
        if (buf[0]!=0)
            add_history(buf);
        free( cmd_prefix );

        return( buf );
    }
 
    free( cmd_prefix );
    free( buf );
 
    return "";
}
 
static char** my_completion( const char * text , int start,  int end)
{
    char **matches;
 
    matches = (char **)NULL;
 
    if (start == 0)
        matches = rl_completion_matches ((char*)text, &my_generator);
    else
        rl_bind_key('\t',rl_abort);
 
    return (matches);
 
}
 
char* my_generator(const char* text, int state)
{
    static int list_index, len;
    char *name;
 
    if (!state) {
        list_index = 0;
        len = strlen (text);
    }
 
    while (name = cmd[list_index]) {
        list_index++;

        if (strncmp (name, text, len) == 0)
            return (dupstr(name));
    }
 
    /* If no names matched, then return NULL. */
    return ((char *)NULL);
 
}
 
char * dupstr (char* s) {
  char *r;
 
  r = (char*) xmalloc ((strlen (s) + 1));
  strcpy (r, s);
  return (r);
}
 
void * xmalloc (int size)
{
    void *buf;
 
    buf = malloc (size);
    if (!buf) {
        fprintf (stderr, "Error: Out of memory. Exiting.'n");
        exit (1);
    }
 
    return buf;
}

#ifdef _CPLUSPLUS
}
#endif
