//=============================================================================
//  @brief  Implementations (bodies) of extern functions RESSL copy command (policy pattern)
//  @author Bryan Morris, Jeff McNeal, Verilab (www.verilab.com)
// =============================================================================
//
//                      RESSL SystemVerilab Utilities Library
//
// @File: ressl_impl_Commands_copy.svh
//
// Copyright 2015 Verilab, Inc.
// 
//    Licensed under the Apache License, Version 2.0 (the "License");
//    you may not use this file except in compliance with the License.
//    You may obtain a copy of the License at
// 
//        http://www.apache.org/licenses/LICENSE-2.0
// 
//    Unless required by applicable law or agreed to in writing, software
//    distributed under the License is distributed on an "AS IS" BASIS,
//    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//    See the License for the specific language governing permissions and
//    limitations under the License.
//=============================================================================

// -------------------- Strategy / Policy patterns

// ---- copy_cmd Implementation
                                    
// Syntax : copy <seq_name> <copy_name>
task copy_cmd::execute( 
   input string args[$],
   ref  boolean is_command_valid
 );
   string       my_seq_name, my_copy_name;
   uvm_sequence_base my_copy_seq;

   // Grab the right sequence
   my_seq_name  = args[0];
   my_copy_name = args[1];

   // Does the supplied sequence name exist?
   if (!this.ressl_.m_sequence_registry.exists(my_seq_name)) begin
      this.ressl_.stderr(.err_msg($sformatf("Could not find the original sequence name %s", my_seq_name)),
                         .help_msg("Use the list command to find the sequence you're looking for.. or type it correctly. ;-)"));
      is_command_valid = FALSE;
      return;
   end

   this.ressl_.stderr("copy command is not implemented yet.");
   
   // // Otherwise, clone the existing sequence.
   // my_copy_seq = this.ressl_.m_sequence_registry[my_seq_name][0].clone();
   // if (my_copy_seq == null) begin
   //    this.ressl_.stderr( .err_msg($sformatf("Failed to copy sequence name %s.\n", my_seq_name)) );
   //    is_command_valid = FALSE;
   //    return;
   // end
   
   // // Then add it to the registry.
   // if (this.ressl_.add_to_sequence_registry(my_copy_name, my_copy_seq) == FALSE) begin
   //    this.ressl_.stderr( .err_msg($sformatf("That's odd... cannot add %s to the sequence registry", my_copy_name)),
   //                        .help_msg("...uhh... do you already something in the register with the same name?! Or debug it and send us the fix. ;-)") );
   //    is_command_valid = FALSE;
   // end
endtask : execute 

function string copy_cmd::help( );
   help = "copy <seq_name <copy_name>";
endfunction : help

