//=============================================================================
//  @brief  Implementations (bodies) of extern functions RESSL describe command
//  @author Bryan Morris, Jeff McNeal, Verilab (www.verilab.com)
// =============================================================================
//
//                      RESSL SystemVerilab Utilities Library
//
// @File: ressl_impl_Commands_describe.svh
//
// Copyright 2015 Verilab, Inc.
// 
//    Licensed under the Apache License, Version 2.0 (the "License");
//    you may not use this file except in compliance with the License.
//    You may obtain a copy of the License at
// 
//        http://www.apache.org/licenses/LICENSE-2.0
// 
//    Unless required by applicable law or agreed to in writing, software
//    distributed under the License is distributed on an "AS IS" BASIS,
//    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//    See the License for the specific language governing permissions and
//    limitations under the License.
//=============================================================================

// -------------------- Strategy / Policy patterns

// ---- describe_cmd Implementation
task describe_cmd::execute( 
   input string args[$],
   ref  boolean is_command_valid
);
   string            my_seq_name;
   string            my_repo_key_q[$];
   uvm_sequence_base my_seq;
   uvm_sequencer_base my_seqr;
   seq_info     my_seq_info_q[$];
   
   /*
   $display("executing describe_cmd with args");
   foreach(args[i]) begin
      $display("args[%0d]=%s", i, args[i]);
   end
   // return;
   */
   
   my_seq_name = args[0];
   // If they don't supply a sequence name, just use the currently selected sequence.
   if (my_seq_name == "") begin
      my_seq_name = this.ressl_.get_current_seq_name;
   end

   // Oi vey.  They're using the wild-card. Ok, then.  Go thru all the
   // the sequences and list out their name and type
   if (my_seq_name == "*") begin
      this.ressl_.m_sequence_registry.keys(my_repo_key_q);
      foreach (my_repo_key_q[k]) begin
         if (this.ressl_.m_sequence_registry.get(my_repo_key_q[k], my_seq_info_q)) begin
            foreach (my_seq_info_q[i]) begin
               this.ressl_.stdout($sformatf("\nSequence: %s:%s (type:%s)\n",
                                            my_repo_key_q[k], 
                                            my_seq_info_q[i].get_seq().get_name(),
                                            my_seq_info_q[i].get_seq().get_type_name()));
            end
         end
      end
   end else begin
   
      // 1st argument must be sequence name found in the sequence registry.
      if ( !this.ressl_.m_sequence_registry.exists( my_seq_name ) ) begin
         this.ressl_.stderr( .err_msg( "try again... this time with a sequence name that exists." ),
                             .help_msg( this.help( ) ));
         is_command_valid = FALSE;
         return;  // no point continuing.
      end

      // sequence exists... ask it to desribe itself
      if (this.ressl_.m_sequence_registry.get(my_seq_name, my_seq_info_q)) begin
         foreach (my_seq_info_q[ i ]) begin
            my_seq = my_seq_info_q[i].get_seq();
            my_seqr = my_seq_info_q[i].get_seqr();
            this.ressl_.stdout($sformatf("[%0d] Sequence: %s (type:%s)[Sequencer type: %s] \n", 
                                         i, my_seq_name, 
                                         my_seq.get_type_name(),
                                         ((my_seqr != null) ? my_seqr.get_type_name() : "unattached")));
            this.ressl_.stdout(my_seq.get_field_members());
            this.ressl_.stdout("\n");
            // this.ressl_.stdout($sformatf("%s[%0d] has %s", 
            //                              my_seq_name, i, 
            //                              my_seq.get_field_members()));
         end
      end
      // ^^^^^^^^^^ TODO: this stuff above here could go into a base ressl_cmd
   end
   this.ressl_.stdout("\n");

endtask : execute

function string describe_cmd::help( );
   help = "describe <sequence name>";
endfunction : help


