//=============================================================================
//  @brief  Implementations (bodies) of extern functions RESSL list command
//  @author Bryan Morris, Jeff McNeal, Verilab (www.verilab.com)
// =============================================================================
//
//                      RESSL SystemVerilab Utilities Library
//
// @File: ressl_impl_Commands_list.svh
//
// Copyright 2015 Verilab, Inc.
// 
//    Licensed under the Apache License, Version 2.0 (the "License");
//    you may not use this file except in compliance with the License.
//    You may obtain a copy of the License at
// 
//        http://www.apache.org/licenses/LICENSE-2.0
// 
//    Unless required by applicable law or agreed to in writing, software
//    distributed under the License is distributed on an "AS IS" BASIS,
//    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//    See the License for the specific language governing permissions and
//    limitations under the License.
//=============================================================================

// -------------------- Strategy / Policy patterns

// ---- list_cmd Implementation
                                    
task list_cmd::execute( 
   input string args[$],
   ref  boolean is_command_valid
);
   string my_seq_name;
   string my_seqr_name;
   string my_prefix;  // to indicate which seq in list is the current, or the default seqr.
   string my_keys[$];
    
   // ensure that the sequence does NOT exist.
   this.ressl_.stdout( "Sequence Registry:\n");
   this.ressl_.m_sequence_registry.keys(my_keys);
   foreach (my_keys[k] ) begin
      my_seq_name = my_keys[k];
      // Print out the name and the number of sub-sequences for each sequence.
      // Indicate the currently selected sequence with an "->" prefix.
      my_prefix = (my_seq_name == this.ressl_.get_current_seq_name()) ? "-> " : "";
      this.ressl_.stdout( $sformatf("\t%s%s [#subseq:%0d] \n",
                                    my_prefix,
                                    my_seq_name,
                                    this.ressl_.m_sequence_registry.num(my_seq_name)));
   end

   // Then display the sequencer 
   this.ressl_.stdout( "Sequencer Registry:\n");
   foreach (this.ressl_.m_sequencer_registry[my_seqr_name] ) begin
      // Print out the name and the type of sequencer
      // Indicate the default seqr
      my_prefix = (my_seqr_name == this.ressl_.m_default_seqr.get_name()) ? "-> " : "";
      this.ressl_.stdout( $sformatf("\t%s%s (type:%s)\n",
                                    my_prefix,
                                    my_seqr_name,
                                    this.ressl_.m_default_seqr.get_type_name()));
   end
   
endtask : execute

function string list_cmd::help( );
   help = "list ";
endfunction : help

