//=============================================================================
//  @brief  Implementations (bodies) of extern functions RESSL load command
//  @author Bryan Morris, Jeff McNeal, Verilab (www.verilab.com)
// =============================================================================
//
//                      RESSL SystemVerilab Utilities Library
//
// @File: ressl_impl_Commands_load.svh
//
// Copyright 2015 Verilab, Inc.
// 
//    Licensed under the Apache License, Version 2.0 (the "License");
//    you may not use this file except in compliance with the License.
//    You may obtain a copy of the License at
// 
//        http://www.apache.org/licenses/LICENSE-2.0
// 
//    Unless required by applicable law or agreed to in writing, software
//    distributed under the License is distributed on an "AS IS" BASIS,
//    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//    See the License for the specific language governing permissions and
//    limitations under the License.
//=============================================================================

// -------------------- Strategy / Policy patterns


// ---- load_cmd Implementation
`define MAX_LINE_LENGTH 1024
task load_cmd::execute( 
   input string args[$],
   ref  boolean is_command_valid
 );
   int my_file_id;
   string my_filename;
   string my_cmd;
   int    my_read_count;
   int unsigned my_line_number;
   string my_verb;
   string my_args[$];
   boolean my_cmd_valid;
   
   my_filename = args[0];

   // Open the file for writing.
   my_file_id = $fopen(my_filename, "r");
   if (my_file_id == 0) begin
      this.ressl_.stderr(.err_msg($sformatf("Could not open file %s for reading.", my_filename)),
                         .help_msg("You probably need to supply the full pathname."));
      is_command_valid = FALSE;
      return;
   end

   my_line_number = 0;
   while ( !$feof(my_file_id)) begin
      my_read_count = $fgets(my_cmd, my_file_id);
      if ($feof(my_file_id)) break;
      if (my_read_count <= 0) begin
         this.ressl_.stderr(.err_msg($sformatf("%s,%0d: Failed to read properly.",
                                               my_filename, my_line_number)),
                            .help_msg("Maybe look at the line.  It needs to be string."));
         is_command_valid = FALSE;
         continue;  // but try the other lines in the file.
      end
      
      this.ressl_.interpret(my_cmd, my_verb, my_args, my_cmd_valid);
      if (my_cmd_valid == FALSE) begin
         this.ressl_.stderr(.err_msg($sformatf("%s,%0d: Failed to execute line: %s",
                                               my_filename, my_line_number, my_cmd)),
                            .help_msg("Not sure why... check that command is correct."));
         is_command_valid = FALSE;
      end
      my_line_number++;
   end
   $fclose(my_file_id);

   this.ressl_.stdout($sformatf("... loading session from file %s complete.\n",my_filename));
endtask : execute

function string load_cmd::help( );
   help = "load <filename>";
endfunction : help

