//=============================================================================
//  @brief  Implementations (bodies) of extern functions for the move RESSL command
//  @author Bryan Morris, Jeff McNeal, Verilab (www.verilab.com)
// =============================================================================
//
//                      RESSL SystemVerilab Utilities Library
//
// @File: ressl_impl_Commands_move.svh
//
// Copyright 2015 Verilab, Inc.
// 
//    Licensed under the Apache License, Version 2.0 (the "License");
//    you may not use this file except in compliance with the License.
//    You may obtain a copy of the License at
// 
//        http://www.apache.org/licenses/LICENSE-2.0
// 
//    Unless required by applicable law or agreed to in writing, software
//    distributed under the License is distributed on an "AS IS" BASIS,
//    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//    See the License for the specific language governing permissions and
//    limitations under the License.
//=============================================================================

// -------------------- Strategy / Policy patterns

// ---- move_cmd Implementation

// Syntax: move <from_index> <to_index>
//   Allows you to move the sub-sequence indicated by <from_index> to <to_index>
//   i.e., change the order of the sub-sequences. 
task move_cmd::execute( 
   input string args[$],
   ref  boolean is_command_valid
);
   string       my_current_seq_name;
   int unsigned my_from_index, my_to_index;
   int unsigned my_seq_size;

   // ensure that the sequence does NOT exist.
   my_from_index = args[0].atoi();
   my_to_index = args[1].atoi();

   // Ensure those indices are meaningful.
   my_current_seq_name = this.ressl_.get_current_seq_name();
   my_seq_size = this.ressl_.m_sequence_registry.num(my_current_seq_name);
   if (my_from_index > my_seq_size) begin
      this.ressl_.stderr( .err_msg( $sformatf("You trying to move sub-seq %0d index which bigger than the size of this sequence.", 
                                              my_from_index) ),
                          .help_msg("Try something smaller." ));
      is_command_valid = FALSE;
   end
   if (my_to_index > my_seq_size) begin
      this.ressl_.stderr( .err_msg( $sformatf("You trying to move sub-seq to index %0d which bigger than the size of this sequence.", 
                                              my_to_index) ),
                          .help_msg("Try something smaller." ));
      is_command_valid = FALSE;
   end

   if (is_command_valid != FALSE) begin
      this.ressl_.m_sequence_registry.move(my_current_seq_name, 
                                           my_from_index, my_to_index);
   end
endtask : execute

function string move_cmd::help( );
   help = "move <from_index> <to_index> ";
endfunction : help


