//=============================================================================
//  @brief  Implementations (bodies) of extern functions RESSL randomize command
//  @author Bryan Morris, Jeff McNeal, Verilab (www.verilab.com)
// =============================================================================
//
//                      RESSL SystemVerilab Utilities Library
//
// @File: ressl_impl_Commands_randomize.svh
//
// Copyright 2015 Verilab, Inc.
// 
//    Licensed under the Apache License, Version 2.0 (the "License");
//    you may not use this file except in compliance with the License.
//    You may obtain a copy of the License at
// 
//        http://www.apache.org/licenses/LICENSE-2.0
// 
//    Unless required by applicable law or agreed to in writing, software
//    distributed under the License is distributed on an "AS IS" BASIS,
//    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//    See the License for the specific language governing permissions and
//    limitations under the License.
//=============================================================================

// -------------------- Strategy / Policy patterns

// ---- randomize_cmd Implementation
                                    
// Syntax : randomize <seq_index>
task randomize_cmd::execute( 
   input string args[$],
   ref  boolean is_command_valid
 );
   int unsigned my_seq_index;
   string       my_attrib, my_value;
   uvm_sequence_base my_uvm_seq;

   // Grab the right sequence
   my_seq_index = args[0].atoi();
   my_attrib    = args[1];
   my_value     = args[2];

   my_uvm_seq = this.ressl_.get_seq(my_seq_index);
   if ( !my_uvm_seq.randomize( ) ) begin
      this.ressl_.stderr( .err_msg( "Failed to randomized sequence...." ),
                          .help_msg( "" ) );
      is_command_valid = FALSE;
      end 
      else begin
         this.ressl_.stdout( .out_msg( "Sequence randomized....\n" ) );
         // TODO: Fix UVM linkage : my_uvm_seq.describe( );
      end
endtask : execute 

function string randomize_cmd::help( );
   help = "randomize <seq_index>";
endfunction : help

