//=============================================================================
//  @brief  Implementations (bodies) of extern functions RESSL save command
//  @author Bryan Morris, Jeff McNeal, Verilab (www.verilab.com)
// =============================================================================
//
//                      RESSL SystemVerilab Utilities Library
//
// @File: ressl_impl_Commands_save.svh
//
// Copyright 2015 Verilab, Inc.
// 
//    Licensed under the Apache License, Version 2.0 (the "License");
//    you may not use this file except in compliance with the License.
//    You may obtain a copy of the License at
// 
//        http://www.apache.org/licenses/LICENSE-2.0
// 
//    Unless required by applicable law or agreed to in writing, software
//    distributed under the License is distributed on an "AS IS" BASIS,
//    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//    See the License for the specific language governing permissions and
//    limitations under the License.
//=============================================================================

// -------------------- Strategy / Policy patterns

// ---- save_cmd Implementation
task save_cmd::execute( 
   input string args[$],
   ref  boolean is_command_valid
 );
   int my_file_id;
   string my_filename;
   
   my_filename = args[0];

   // Open the file for writing.
   my_file_id = $fopen(my_filename, "w");
   if (my_file_id == 0) begin
      this.ressl_.stderr(.err_msg($sformatf("Could not open file %s for writing.", my_filename)),
                         .help_msg("You probably need to supply the full pathname."));
      is_command_valid = FALSE;
      return;
   end
   
   foreach (this.ressl_.save_load_history[i]) begin
      $display("Saving[%0d]: %s", i, this.ressl_.save_load_history[i]);
      $fwrite(my_file_id, "%s\n", this.ressl_.save_load_history[i]);
   end
   $fclose(my_file_id);
   this.ressl_.stdout({"Got it. Saved session to file \n", my_filename});
   // finally clear the history for subsequent commands.
   this.ressl_.save_load_history.delete();
   this.ressl_.stdout("... and cleared the command history.  It's fresh and clean once again.\n");
endtask : execute

function string save_cmd::help( );
   help = "save <filename>";
endfunction : help

