//=============================================================================
//  @brief  Implementations (bodies) of extern functions RESSL select command
//  @author Bryan Morris, Jeff McNeal, Verilab (www.verilab.com)
// =============================================================================
//
//                      RESSL SystemVerilab Utilities Library
//
// @File: ressl_impl_Commands_select.svh
//
// Copyright 2015 Verilab, Inc.
// 
//    Licensed under the Apache License, Version 2.0 (the "License");
//    you may not use this file except in compliance with the License.
//    You may obtain a copy of the License at
// 
//        http://www.apache.org/licenses/LICENSE-2.0
// 
//    Unless required by applicable law or agreed to in writing, software
//    distributed under the License is distributed on an "AS IS" BASIS,
//    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//    See the License for the specific language governing permissions and
//    limitations under the License.
//=============================================================================

// -------------------- Strategy / Policy patterns

// ---- select_cmd Implementation
task select_cmd::execute( 
   input string args[$],
   ref  boolean is_command_valid
 );
   string            my_seq_name;
   uvm_sequence_base my_uvm_seq;

   my_seq_name = args[0];
   
   // Ensure that they've either:
   //     A) selected a pre-existing sequence
   if (this.ressl_.m_sequence_registry.exists(my_seq_name)) begin
      this.ressl_.set_current_sequence(my_seq_name);
   end
   //  OR B) reserve a new slot for this sequence name
   else begin
      this.ressl_.m_sequence_registry.reserve(my_seq_name);
   end
   // In either case, this is the newly selected sequence that the user wants to
   // work with.
   this.ressl_.set_current_sequence(my_seq_name);
endtask : execute

function string select_cmd::help( );
   help = "select <seq_path>";
endfunction : help


