//=============================================================================
//  @brief  Implementations (bodies) of extern functions RESSL set commands
//  @author Bryan Morris, Jeff McNeal, Verilab (www.verilab.com)
// =============================================================================
//
//                      RESSL SystemVerilab Utilities Library
//
// @File: ressl_impl_Commands_set.svh
//
// Copyright 2015 Verilab, Inc.
// 
//    Licensed under the Apache License, Version 2.0 (the "License");
//    you may not use this file except in compliance with the License.
//    You may obtain a copy of the License at
// 
//        http://www.apache.org/licenses/LICENSE-2.0
// 
//    Unless required by applicable law or agreed to in writing, software
//    distributed under the License is distributed on an "AS IS" BASIS,
//    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//    See the License for the specific language governing permissions and
//    limitations under the License.
//=============================================================================

// -------------------- Strategy / Policy patterns


// ---- set_cmd Implementation
// Sets the supplied sequence index (in the currently recording sequence) to {attribute, value}
// Syntax : set <seq_index> <field> <value>
task set_cmd::execute( 
   input string args[$],
   ref  boolean is_command_valid
 );
   int unsigned my_seq_index;
   string       my_field, my_value;
   uvm_sequence_base my_uvm_seq;

   // Grab the right sequence
   my_seq_index = args[0].atoi();
   my_field     = args[1];
   my_value     = args[2];
   // is the value the start of a string? i.e., starts with a "
   
   if (my_value[0] == "\"") begin
      // Grab all remaining args until the closing " (stripping the " as we see them).
      my_value = "";
      for (int unsigned arg_index=2; arg_index < args.size(); arg_index++) begin
         if (arg_index == 2) my_value = svlib_pkg::str_strip(args[arg_index], "\"" );
         else                my_value = { my_value, " ", svlib_pkg::str_strip(args[arg_index], "\"" ) };
         $display("args[%0d]=%s, my_value=%s=", arg_index, args[arg_index],my_value);
      end
   end

   my_uvm_seq = this.ressl_.get_seq(my_seq_index);
   if (my_uvm_seq == null) return;
   
   my_uvm_seq.set_field_value( .field_name( my_field ), .field_value( my_value ) );

endtask : execute

function string set_cmd::help( );
   help = "set <seq_index> <field> <value>";
endfunction : help

