//=============================================================================
//  @brief  Implementations (bodies) of extern functions RESSL start command
//  @author Bryan Morris, Jeff McNeal, Verilab (www.verilab.com)
// =============================================================================
//
//                      RESSL SystemVerilab Utilities Library
//
// @File: ressl_impl_Commands_start.svh
//
// Copyright 2015 Verilab, Inc.
// 
//    Licensed under the Apache License, Version 2.0 (the "License");
//    you may not use this file except in compliance with the License.
//    You may obtain a copy of the License at
// 
//        http://www.apache.org/licenses/LICENSE-2.0
// 
//    Unless required by applicable law or agreed to in writing, software
//    distributed under the License is distributed on an "AS IS" BASIS,
//    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//    See the License for the specific language governing permissions and
//    limitations under the License.
//=============================================================================

// -------------------- Strategy / Policy patterns

// ---- start_cmd Implementation

// start_cmd: Actually run the sequence
// Syntax: start [repeat_count]
task start_cmd::execute(
   input string args[$],
   ref   boolean is_command_valid  
);
   string       my_seq_name;   // todo: consider moving to base clas
   int unsigned my_repeat_count;
   uvm_sequence_base my_seq; 
   uvm_sequencer_base my_seqr; 
   seq_info     my_seq_info_q[$];        // todo: consider moving to base class

   is_command_valid = TRUE;

   // see if the sequence exists
   // Default to 1 
   if(args[0] == "") begin
       my_repeat_count = 1;
   end else begin
      my_repeat_count = args[0].atoi();
   end
   if (my_repeat_count == 0) begin
      this.ressl_.stderr(.err_msg("You set the repeat_count to 0?!  Really?!"),
                         .help_msg(this.help()));
      is_command_valid = FALSE;
      return;
   end

   my_seq_name = this.ressl_.get_current_seq_name();
   repeat( my_repeat_count) begin
      if (this.ressl_.m_sequence_registry.get(my_seq_name, my_seq_info_q) == 1) begin
         foreach (my_seq_info_q[i]) begin
            my_seq = my_seq_info_q[i].get_seq();
            //my_seq.randomize();
            my_seqr = my_seq_info_q[i].get_seqr();
            // If they've left it unattached (which shouldn't happen), then use the default. 
            if (my_seqr == null) my_seqr = this.ressl_.m_default_seqr;
            $display("BJM[%0d]:seq=%s m_default_seqr=%s", i,my_seq.get_name(),((this.ressl_.m_default_seqr != null) ? this.ressl_.m_default_seqr.get_type_name() : "null"));
            my_seqr.print();
            my_seq.start( my_seqr );
         end
      end
   end
endtask : execute                              

function string start_cmd::help( );
   help = "start [repeat_count] = Execute the currently selected sequence [repeat_count] times.";
endfunction : help

