//=============================================================================
//  @brief  ressl_pkg imports and includes
//  @author Bryan Morris, Jeff McNeal, Verilab (www.verilab.com)
// =============================================================================
//
//                      RESSL SystemVerilab Utilities Library
//
// @File: ressl_pkg.sv
//
// Copyright 2015 Verilab, Inc.
// 
//    Licensed under the Apache License, Version 2.0 (the "License");
//    you may not use this file except in compliance with the License.
//    You may obtain a copy of the License at
// 
//        http://www.apache.org/licenses/LICENSE-2.0
// 
//    Unless required by applicable law or agreed to in writing, software
//    distributed under the License is distributed on an "AS IS" BASIS,
//    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//    See the License for the specific language governing permissions and
//    limitations under the License.
//=============================================================================
`ifndef RESSL_PKG_DEFINED
`define RESSL_PKG_DEFINED

package ressl_pkg;
   import uvm_pkg::*;
   `include "uvm_macros.svh"
   import svlib_pkg::*;

   `include "ressl_dpi_imports.svh"
   
   // TODO: not the best.  But would rather this than a bit.
   typedef enum { FALSE = 0, TRUE = 1 } boolean;

   // add_new_ressl_cmd: convenience macro to add a new ressl_cmd to the set of
   // commands.
   // Input Parameters:
   //   RESSL ; handle to the ressl instance you want to attach the command.
   //   NAME  : the 'verb' for the comand i.e., the first verb.  Must be unique.
`define add_new_ressl_cmd(RESSL, NAME) \
   RESSL.add_new_ressl_cmd("NAME", NAME``_cmd::type_id::create( "NAME``_cmd" )); \
   RESSL.verbs_["NAME"].set_ressl(this);

  // Utility classes
  `include "ressl_pkg_seq_info.svh"
  `include "ressl_pkg_registry.svh"

   // Commands
  `include "ressl_pkg_Commands.svh"
  `include "ressl_pkg_Commands_add.svh"
  `include "ressl_pkg_Commands_attach.svh"
  `include "ressl_pkg_Commands_copy.svh"
  `include "ressl_pkg_Commands_create.svh"
  `include "ressl_pkg_Commands_describe.svh"
  `include "ressl_pkg_Commands_help.svh"
  `include "ressl_pkg_Commands_list.svh"
  `include "ressl_pkg_Commands_load.svh"
  `include "ressl_pkg_Commands_move.svh"
  `include "ressl_pkg_Commands_quit.svh"
  `include "ressl_pkg_Commands_randomize.svh"
  `include "ressl_pkg_Commands_save.svh"
  `include "ressl_pkg_Commands_select.svh"
  `include "ressl_pkg_Commands_set.svh"
  `include "ressl_pkg_Commands_start.svh"

  `include "ressl_pkg_Ressl.svh"

endpackage

`endif
