//=============================================================================
//  @brief  types and classes for RESSL commands (Read-Evaluate-StartSequence-Loop)
//  @author Bryan Morris, Jeff McNeal, Verilab (www.verilab.com)
// =============================================================================
//
//                      RESSL SystemVerilab Utilities Library
//
// @File: ressl_pkg_Commands.svh
//
// Copyright 2015 Verilab, Inc.
// 
//    Licensed under the Apache License, Version 2.0 (the "License");
//    you may not use this file except in compliance with the License.
//    You may obtain a copy of the License at
// 
//        http://www.apache.org/licenses/LICENSE-2.0
// 
//    Unless required by applicable law or agreed to in writing, software
//    distributed under the License is distributed on an "AS IS" BASIS,
//    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//    See the License for the specific language governing permissions and
//    limitations under the License.
//=============================================================================

// Forward declarations
typedef class ressl;

// -------------------- Strategy / Policy patterns

//TODO: Extract input ressl and place it into the constructor.
//TODO: Command self-regsiters itself with the associated ressl.
virtual class ressl_cmd extends uvm_object;
   static protected string help_;
   protected ressl         ressl_;
   protected boolean       save_this_cmd_;

   function new(string name = "");
      // MOST commands should NOT be saved to save-load file. Only those that
      // change the structure of the datbase e.g., add, delete.
      this.save_this_cmd_ = FALSE;
   endfunction : new
   
   pure virtual task execute( input string args[$], ref boolean is_command_valid );
   pure virtual function string help();
   virtual function void set_ressl(input ressl ressl);
      this.ressl_ = ressl;
   endfunction : set_ressl
   virtual function boolean is_saveable();
      return this.save_this_cmd_;
   endfunction : is_saveable

   // ==== Utility functions: encapsulate common patterns used by many commands.

endclass : ressl_cmd


// ============================================================================
/////////////////// IMPLEMENTATIONS OF EXTERN CLASS METHODS ///////////////////

`include "ressl_impl_Commands.svh"
