//=============================================================================
//  @brief  classes to hold the (seq,seqr) pair (held in the Ressl registry)
//  @author Bryan Morris, Jeff McNeal, Verilab (www.verilab.com)
// =============================================================================
//
//                      svlib SystemVerilab Utilities Library
//
// @File: svlib_pkg_Ressl.svh
//
// Copyright 2015 Verilab, Inc.
// 
//    Licensed under the Apache License, Version 2.0 (the "License");
//    you may not use this file except in compliance with the License.
//    You may obtain a copy of the License at
// 
//        http://www.apache.org/licenses/LICENSE-2.0
// 
//    Unless required by applicable law or agreed to in writing, software
//    distributed under the License is distributed on an "AS IS" BASIS,
//    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//    See the License for the specific language governing permissions and
//    limitations under the License.
//=============================================================================

// This is the item in the registry.  It is a pair that has a 1:1 correspondence between
// sequence and sequencer.  Although the goal is to allow this to be a container
// of other meta-data regarding the sequence (if necessary).
//  
class seq_info extends uvm_object;
   local uvm_sequence_base  seq_;
   local uvm_sequencer_base seqr_;

   `uvm_object_utils_begin(seq_info)
   `uvm_object_utils_end
   
   function new(string name="seq_seqr_info");
      super.new(name);
      this.seq_ = null;
      this.seqr_ = null;
   endfunction : new
   function void set_seq(input uvm_sequence_base seq);
      this.seq_ = seq;
   endfunction : set_seq
   function void set_seqr(input uvm_sequencer_base seqr);
      this.seqr_ = seqr;
   endfunction : set_seqr

   function uvm_sequence_base get_seq();
      return(this.seq_);
   endfunction : get_seq
   function uvm_sequencer_base get_seqr();
      return(this.seqr_);
   endfunction : get_seqr
endclass : seq_info

